@@ -13,8 +13,6 @@ from PySide2.QtCore import Qt, QSize, QEvent, QTimer, QUrl
 import angr
 import angr.flirt
 
-from .toolbar_manager import ToolbarManager
-
 try:
     from angr.angrdb import AngrDB
 except ImportError:
@@ -50,7 +48,8 @@ from .dialogs.load_docker_prompt import LoadDockerPrompt, LoadDockerPromptError
 from .dialogs.new_state import NewState
 from .dialogs.about import LoadAboutDialog
 from .dialogs.preferences import Preferences
-from .toolbars import FileToolbar, SimgrToolbar
+from .toolbars import FileToolbar, DebugToolbar
+from .toolbar_manager import ToolbarManager
 
 if TYPE_CHECKING:
     from PySide2.QtWidgets import QApplication
@@ -94,9 +93,9 @@ class MainWindow(QMainWindow):
         self._help_menu = None
         self._plugin_menu = None
 
-        self._init_toolbars()
         self._init_statusbar()
         self._init_workspace()
+        self._init_toolbars()
         self._init_menus()
         self._init_plugins()
         self._init_library_docs()
@@ -212,7 +211,7 @@ class MainWindow(QMainWindow):
         self.statusBar().addPermanentWidget(self._progressbar)
 
     def _init_toolbars(self):
-        for cls in (FileToolbar, SimgrToolbar):
+        for cls in (FileToolbar, DebugToolbar):
             self.toolbar_manager.show_toolbar_by_class(cls)
 
     #
