@@ -13,3 +13,5 @@ from .proximity_view import ProximityView
 from .types_view import TypesView
 from .hex_view import HexView
 from .log_view import LogView
+from .registers_view import RegistersView
+from .stack_view import StackView
